@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -60,12 +60,12 @@ import com.openexchange.dataretention.csv.CSVDataRetentionConfig;
 
 /**
  * {@link CSVFileCreationCallable} - Task for proper CSV file creation.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 final class CSVFileCreationCallable implements Callable<Boolean> {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(CSVFileCreationCallable.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(CSVFileCreationCallable.class));
 
     /**
      * Atomic counter for file creations.
@@ -79,7 +79,7 @@ final class CSVFileCreationCallable implements Callable<Boolean> {
 
     /**
      * Initializes a new {@link CSVFileCreationCallable}.
-     * 
+     *
      * @param writeTask The invoking write task.
      */
     CSVFileCreationCallable(final AbstractWriteTask writeTask) {
@@ -158,7 +158,7 @@ final class CSVFileCreationCallable implements Callable<Boolean> {
 
     /**
      * Appends formatted file number to specified string builder.
-     * 
+     *
      * @param fileNumber The file number to format
      * @param sb The string builder to append to
      */
